@@ -100,7 +100,7 @@ EXCLUDE_PATTERNS = [r'\.pyc$|\.pyo$|\.orig$|\.hg|\.svn|build',
 
 # Name filters for file/project explorers (excluding files without extension)
 NAME_FILTERS = ['*' + _ext for _ext in VALID_EXT + SHOW_EXT if _ext]+\
-               ['README', 'INSTALL', 'LICENSE']
+               ['README', 'INSTALL', 'LICENSE', 'CHANGELOG']
 
 DEFAULTS = [
             ('main',
@@ -187,8 +187,10 @@ DEFAULTS = [
               'show_elapsed_time': True,
               'show_icontext': False,
               'monitor/enabled': True,
+              'qt/install_inputhook': os.name == 'nt' \
+                                      or os.environ.get('QT_API') == 'pyside',
+              'qt/api': 'default',
               'pyqt/api_version': 0,
-              'pyqt/replace_inputhook': os.name == 'nt',
               'pyqt/ignore_sip_setapi_errors': False,
               'matplotlib/patch': True,
               'matplotlib/backend/enabled': True,
@@ -198,6 +200,8 @@ DEFAULTS = [
               'umd/namelist': ['guidata', 'guiqwt'],
               'light_background': True,
               'ipython_set_color': True,
+              'merge_output_channels': os.name != 'nt',
+              'colorize_sys_stderr': os.name != 'nt',
               }),
             ('variable_explorer',
              {
@@ -242,6 +246,7 @@ DEFAULTS = [
               'calltips': True,
               'go_to_definition': True,
               'close_parentheses': True,
+              'add_colons': True,
               'auto_unindent': True,
               'indent_chars': '*    *',
               'tab_stop_width': 40,
@@ -357,7 +362,7 @@ DEFAULTS = [
 
 DEV = not __file__.startswith(sys.prefix)
 DEV = False
-CONF = UserConfig('spyder', defaults=DEFAULTS, load=(not DEV), version='2.2.0',
+CONF = UserConfig('spyder', defaults=DEFAULTS, load=(not DEV), version='2.4.0',
                   subfolder=SUBFOLDER, backup=True, raw_mode=True)
 # Removing old .spyder.ini location:
 old_location = osp.join(get_home_dir(), '.spyder.ini')
