@@ -10,11 +10,14 @@ Spyder third-party plugins configuration management
 
 import os
 import os.path as osp
+import sys
 
 # Local imports
 from spyderlib.utils import programs
 
 
+# Calculate path to `spyderplugins` package, where Spyder looks for all 3rd
+# party plugin modules
 PLUGIN_PATH = None
 if programs.is_module_installed("spyderplugins"):
     import spyderplugins
@@ -25,7 +28,7 @@ if programs.is_module_installed("spyderplugins"):
 
 
 def get_spyderplugins(prefix, extension):
-    """Scan spyderplugins module and
+    """Scan directory of `spyderplugins` package and
     return the list of module names matching *prefix* and *extension*"""
     plist = []
     if PLUGIN_PATH is not None:
@@ -40,7 +43,16 @@ def get_spyderplugins(prefix, extension):
 
 
 def get_spyderplugins_mods(prefix, extension):
-    """Scan spyderplugins module and
-    return the list of modules matching *prefix* and *extension*"""
-    return [getattr(__import__('spyderplugins.%s' % modname), modname)
-            for modname in get_spyderplugins(prefix, extension)]
+    """Import modules that match *prefix* and *extension* from
+    `spyderplugins` package and return the list"""
+    modlist = []
+    for modname in get_spyderplugins(prefix, extension):
+        name = 'spyderplugins.%s' % modname
+        try:
+            __import__(name)
+            modlist.append(sys.modules[name])
+        except Exception, exc:
+            sys.stderr.write(
+                "ERROR: 3rd party plugin import failed for `%s`\n" % modname)
+            sys.stderr.write("---->: %s\n" % exc)
+    return modlist
