@@ -18,13 +18,13 @@ from spyderlib.qt.QtGui import (QHBoxLayout, QWidget, QTreeWidgetItem,
 from spyderlib.qt.QtCore import SIGNAL, Qt, QThread, QMutexLocker, QMutex
 from spyderlib.qt.compat import getexistingdirectory
 
-import sys, os, re, fnmatch
+import sys
+import os
+import re
+import fnmatch
 import os.path as osp
 from subprocess import Popen, PIPE
 
-# For debugging purpose:
-STDOUT = sys.stdout
-
 # Local imports
 from spyderlib.utils import programs
 from spyderlib.utils.qthelpers import (get_std_icon, create_toolbutton,
@@ -780,6 +780,8 @@ class FindInFilesWidget(QWidget):
         """Current search thread has finished"""
         self.find_options.ok_button.setEnabled(True)
         self.find_options.stop_button.setEnabled(False)
+        if self.search_thread is None:
+            return
         found = self.search_thread.get_results()
         self.stop_and_reset_thread()
         if found is not None:
