@@ -24,8 +24,6 @@ import threading
 from time import time
 from subprocess import Popen
 
-STDOUT = sys.stdout
-
 from spyderlib.qt.QtGui import QMessageBox
 from spyderlib.qt.QtCore import SIGNAL, QObject
 
@@ -190,7 +188,6 @@ class InternalShell(PythonShellWidget):
         data = self.interpreter.stdout_write.empty_queue()
         if data:
             self.write(data)
-            self.repaint()
         
     def stderr_avail(self):
         """Data is available in stderr, let's empty the queue and write it!"""
@@ -198,7 +195,6 @@ class InternalShell(PythonShellWidget):
         if data:
             self.write(data, error=True)
             self.flush(error=True)
-            self.repaint()
 
 
     #----- Menus, actions, ...
@@ -259,7 +255,7 @@ class InternalShell(PythonShellWidget):
 
     #------ I/O
     def flush(self, error=False, prompt=False):
-        """Reimplement PythonShellWidget method"""
+        """Reimplement ShellBaseWidget method"""
         PythonShellWidget.flush(self, error=error, prompt=prompt)
         if self.interrupted:
             self.interrupted = False
